@@ -26,19 +26,13 @@ import GHC.Base (quotInt, remInt)
 import GHC.Num (quotRemInteger)
 import GHC.Types (Int(..))
 
-#ifdef  __GLASGOW_HASKELL__
-# if __GLASGOW_HASKELL__ < 611
-import GHC.Integer.Internals
-# else
+#if defined(INTEGER_GMP)
 import GHC.Integer.GMP.Internals
-# endif
+#elif defined(INTEGER_SIMPLE)
+import GHC.Integer.Simple.Internals
 #endif
 
-#ifdef INTEGER_GMP
-# define PAIR(a,b) (# a,b #)
-#else
-# define PAIR(a,b) (a,b)
-#endif
+#define PAIR(a,b) (# a,b #)
 
 integral :: (Integral a, Show a) => a -> Builder
 {-# RULES "integral/Int" integral = bounded :: Int -> Builder #-}
@@ -106,7 +100,9 @@ int = integral
 {-# INLINE int #-}
 
 integer :: Integer -> Builder
+#if defined(INTEGER_GMP)
 integer (S# i#) = int (I# i#)
+#endif
 integer i
     | i < 0     = minus `mappend` go (-i)
     | otherwise = go i
